package com.ics.admin.controller.meeting;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ics.common.core.domain.R;
import com.ics.common.core.controller.BaseController;
import com.ics.admin.domain.meeting.UserEquipment;
import com.ics.admin.service.meeting.IUserEquipmentService;
import org.wf.jwtp.annotation.RequiresPermissions;

/**
 * 用户设备关联 提供者
 *
 * @author chen
 * @date 2024-02-25
 */
@RestController
@RequestMapping("/meeting/userEquipment")
public class UserEquipmentController extends BaseController {

    @Autowired
    private IUserEquipmentService userEquipmentService;

    /**
     * 查询用户设备关联
     */
    @GetMapping("get/{id}")
    public UserEquipment get(@PathVariable("id") Long id) {
        return userEquipmentService.selectUserEquipmentById(id);
    }

    /**
     * 查询用户设备关联列表
     */
    @RequiresPermissions("meeting:userEquipment:list")
    @GetMapping("list")
    public R list(UserEquipment userEquipment) {
        startPage();
        return result(userEquipmentService.selectUserEquipmentList(userEquipment));
    }


    /**
     * 新增保存用户设备关联
     */
    @RequiresPermissions("meeting:userEquipment:add")
    @PostMapping("save")
    public R addSave(@RequestBody UserEquipment userEquipment) {
        return toAjax(userEquipmentService.insertUserEquipment(userEquipment));
    }

    /**
     * 修改保存用户设备关联
     */
    @RequiresPermissions("meeting:userEquipment:edit")
    @PostMapping("update")
    public R editSave(@RequestBody UserEquipment userEquipment) {
        return toAjax(userEquipmentService.updateUserEquipment(userEquipment));
    }

    /**
     * 删除用户设备关联
     */
    @RequiresPermissions("meeting:userEquipment:remove")
    @PostMapping("remove")
    public R remove(String ids) {
        return toAjax(userEquipmentService.deleteUserEquipmentByIds(ids));
    }



}
