package com.ics.admin.mapper.meeting;

import com.ics.admin.domain.meeting.Reservation;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ics.admin.domain.meeting.RoomContent;
import org.apache.ibatis.annotations.Mapper;

import java.util.Date;
import java.util.List;

/**
 * 预约记录Mapper接口
 * 
 * @author chen
 * @date 2024-02-25
 */
@Mapper
public interface ReservationMapper extends BaseMapper<Reservation> {
    /**
     * 查询预约记录
     * 
     * @param id 预约记录ID
     * @return 预约记录
     */
    Reservation selectReservationById(Long id);

    /**
     * 查询预约记录列表
     * 
     * @param reservation 预约记录
     * @return 预约记录集合
     */
    List<Reservation> selectReservationList(Reservation reservation);

    /**
     * 新增预约记录
     * 
     * @param reservation 预约记录
     * @return 结果
     */
    int insertReservation(Reservation reservation);

    /**
     * 修改预约记录
     * 
     * @param reservation 预约记录
     * @return 结果
     */
    int updateReservation(Reservation reservation);

    /**
     * 删除预约记录
     * 
     * @param id 预约记录ID
     * @return 结果
     */
    int deleteReservationById(Long id);

    /**
     * 批量删除预约记录
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteReservationByIds(String[] ids);

    List<Date> selectListByDate(Long meetingRoomId);

    List<Reservation> todayMeeting(Long id);

    List<Reservation> selectReservationListByDay();

}
