package com.ics.system.service;

import com.ics.common.core.domain.Ztree;
import com.ics.system.domain.Dept;
import com.ics.system.domain.Role;

import java.util.List;
import java.util.Set;

/**
 * 部门管理 服务层
 *
 */
public interface IDeptService {
    /**
     * 查询部门管理数据
     *
     * @param dept 部门信息
     * @return 部门信息集合
     */
    List<Dept> selectDeptList(Dept dept);

    /**
     * 查询部门管理树
     *
     * @param dept 部门信息
     * @return 所有部门信息
     */
    List<Ztree> selectDeptTree(Dept dept);

    /**
     * 根据角色ID查询菜单
     *
     * @param role 角色对象
     * @return 菜单列表
     */
    List<Ztree> roleDeptTreeData(Role role);

    /**
     * 查询部门人数
     *
     * @param parentId 父部门ID
     * @return 结果
     */
    int selectDeptCount(Long parentId);

    /**
     * 查询部门是否存在用户
     *
     * @param deptId 部门ID
     * @return 结果 true 存在 false 不存在
     */
    boolean checkDeptExistUser(Long deptId);

    /**
     * 删除部门管理信息
     *
     * @param deptId 部门ID
     * @return 结果
     */
    int deleteDeptById(Long deptId);

    /**
     * 新增保存部门信息
     *
     * @param dept 部门信息
     * @return 结果
     */
    int insertDept(Dept dept);

    /**
     * 修改保存部门信息
     *
     * @param dept 部门信息
     * @return 结果
     */
    int updateDept(Dept dept);

    /**
     * 根据部门ID查询信息
     *
     * @param deptId 部门ID
     * @return 部门信息
     */
    Dept selectDeptById(Long deptId);

    /**
     * 校验部门名称是否唯一
     *
     * @param dept 部门信息
     * @return 结果
     */
    String checkDeptNameUnique(Dept dept);

    /**
     * 根据角色ID查询部门编号
     *
     * @param roleId 角色编号
     * @return 部门编号
     */
    Set<String> roleDeptIds(Long roleId);

    /**
     * 查找默认部门
     *
     * @return 默认部门，若不存在则返回null
     */
    Dept findDefault();


    /**
     * 新增保存园区信息
     *
     * @param dept 园区信息
     * @return 结果
     */
    int insertPark(Dept dept);


    /**
     * 查询子部门ids
     * @param ancestors
     * @return
     */
    List<Dept> selectChildrenIds(String ancestors);

    /**
     * 查看父级部门
     * @return
     */
    Long selectParent(Long tenantId);



}
